#!/usr/bin/env python
#coding=utf-8

import onelab
import math, os
import string

from rlcompleter import readline
def extract(filename,i,j):
    input = open(filename,'r')
    all_lines = input.readlines()
    input.close()
    if i == -1:
        i = len(all_lines) # last line
    items = all_lines[i-1].split()
    return float(items[j-1])

remote = 'vm@amzyan.local'
remote = ''
if remote :
    workdir = 'CYLINDER/' # the terminating "/" is important
else :
    workdir = onelab.path(__file__) # we work in the directory where the script is located
print("Check local working directory: %s = %s" % (os.getcwd(), workdir))

OL = onelab.client()

if remote :
    # files in 'foam' are not modified by the metamodel
    # so that the synchronizationis actually done only once, 
    # at the first call of the metamodel.
    os.system('rsync -e ssh -avur foam ' + remote + ':' + workdir)
    OL.upload(onelab.path(__file__, 'run.sh'),
                  onelab.path(workdir), remote)    
    OL.upload(onelab.path(__file__, 'foam2gmsh.py'),
                  onelab.path(workdir), remote)    

# Display the geometry in the GUI
OL.reloadGeometry(onelab.path(__file__, 'grid.geo'))

# Check for Onelab parameters in the .geo file
# Gmsh is called with OL.run because it is native
OL.run('mesher', 'gmsh - ' +  onelab.path(__file__, 'grid.geo'),'')

# Check that Onelab parameters defined in 'grid.geo' are now accessible with OL.get
print('radius = %g' % OL.getNumber('Foam/Geometry/radiusMesh'))

# Define Onelab parameters for openFoam
nbIter = OL.defineNumber('Foam/nbIter', value=300, label='number of iterations')
wrInter = OL.defineNumber('Foam/wrInter', value=100, label='write interval')
mshfile = OL.defineString('Foam/meshFile', value='grid.msh', label='Mesh file',
                          choices=('grid1.msh','grid2.msh','grid3.msh') )

# Preprocess OpenFOAM input files
OL.preProcess(onelab.path(__file__, 'controlDict.ol'))

# we're done with the "check" phase
if OL.action == 'check' :
   exit(1)

OL.run('mesher', 'gmsh ' +  onelab.path(__file__, 'grid.geo'),'-3')
#Remark: this step is probably not necessary if meshes are pregenerated.

# Display the mesh selected by the user
OL.mergeFile(onelab.path(__file__, mshfile))

OL.upload(onelab.path(__file__, mshfile),
          onelab.path(workdir,'mesh.msh'), remote)
OL.upload(onelab.path(__file__, 'controlDict'),
          onelab.path(workdir, 'foam/system'), remote)

# OL.call_remote(remote, 'VALVE', 'bash run.sh', onelab.path(__file__, 'valve.log'))
OL.call('bash run.sh', remote, rundir=workdir)

if remote:
   OL.download(onelab.path(__file__),
               onelab.path(workdir, 'run/postProcessing/surfaces/0/U_constantPlane.raw'),
               remote)
   OL.download(onelab.path(__file__),
               onelab.path(workdir, 'run/postProcessing/surfaces/0/p_constantPlane.raw'),
               remote)

OL.download(onelab.path(__file__),
     onelab.path(workdir, 'run/postProcessing/forces/0/forceCoeffs.dat'))
frcd = extract(onelab.path(__file__, 'forceCoeffs.dat'), -1, 2)
frcl = extract(onelab.path(__file__, 'forceCoeffs.dat'), -1, 3)

OL.setNumber('Foam/Solution/cd', value=frcd, label='Drag Coefficient [-]', 
	attributes={'Highlight':'Coral'})
OL.setNumber('Foam/Solution/cl', value=frcl, label='Lift Coefficient [-]', 
	attributes={'Highlight':'Coral'})
OL.addNumberChoice('Foam/Solution/cd', frcd)
OL.addNumberChoice('Foam/Solution/cl', frcl)

OL.mergeFile(onelab.path(__file__, 'p_constantPlane.pos'))
OL.mergeFile(onelab.path(__file__, 'U_constantPlane.pos'))
OL.sendCommand('BoundingBox{-5,5,-5,5,0,1};')

exit(1)








